@@ -1,14 +1,14 @@
 package Text::MagicTemplate::Utilities;
-$VERSION = '0.04';
+$VERSION = '0.06';
 use Exporter ();
 push @ISA, qw( Exporter );
-@EXPORT_OK =  qw( _block );
+@EXPORT_OK =  qw( _parse );
 
 use strict; no strict "refs";
 
 ## set_identifier_output
 
-sub _block
+sub _parse
 {
     my ($s, $content, $ref) = @_;
     my $output = "IDENTIFIERS LIST";
@@ -20,18 +20,18 @@ sub _block
 sub _extract
 {
     my ($c, $content, $level, $output) = @_;
-    my ($S, $I, $E) = $c->syntax;
-    $output .=  _label($c, $1, $2, $3, $level) while $content =~ /$S (\w+) $E (?: (.*?) $S ($I \1 ) $E )?/xgs ;
+    my ($S, $I, $E, $A, $ID) = @{$c.'::SYNTAX'};
+    $output .=  _label($c, $1, $2, $3, $level) while $content =~ / $S($ID)$A$E  (?: ( (?: (?! $S\1$A$E) (?! $S$I\1$E) . )* )  $S($I\1)$E )?/xgs ;
     $output;
 }
 
 sub _label
 {
     my($c, $start_lab, $content, $end_lab, $level, $output ) = @_;
-    my ($S, $I, $E) = $c->syntax;
+    my ($S, $I, $E, $A, $ID) = @{$c.'::SYNTAX'};
     $output .=  ": \n". "\t" x $level . $start_lab;
     $output .= _extract( $c, $content, $level+1 ) if $content;
-    if    ($end_lab and $content =~ /$S \w+ $E/x ) { $output .= ": \n" }
+    if    ($end_lab and $content =~ /$S $ID $A $E/x ) { $output .= ": \n" }
     elsif ($end_lab) { $output .= '...' }
     $output .= "\t" x $level . $end_lab if $end_lab;
     $output;
@@ -40,6 +40,4 @@ sub _label
 ## end set_identifier_output
 
 
-
-
 1;
\ No newline at end of file
